##  Creating and Importing Diagrams from Lucidchart
Once you've set up Lucidchart for your workspace, you can create new diagrams directly within Lucidchart or import existing documents from Lucidchart into SAP LeanIX. You can share the imported diagrams with others in the workspace or add them to dashboards for analysis and communication purposes.
To create or import diagrams from Lucidchart, follow these steps:
  1. Navigate to the Diagrams tab.
  2. Click + New Diagram.
  3. On the Lucidchart overlay, depending on your need, click Create Lucidchart or Import existing document from Lucidchart.
    1. Choosing to create prompts you to provide a title for the document and leads you to Lucidchart.
    2. Choosing to import leads you to Lucidchart, where you can select the documents to import.
![Creating and Importing Diagrams from Lucidchart](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275402f77a4410149e09c2b8f23e5bcc_LowRes.png)
Creating and Importing Diagrams from Lucidchart
